@@ -12,7 +12,6 @@ import (
 	"strconv"
 	"time"
 
-	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/logrusorgru/aurora"
 	"github.com/spf13/cobra"
 	"github.com/superfly/flyctl/api"
@@ -39,7 +38,7 @@ func New(usage, short, long string, fn Runner, p ...preparers.Preparer) *cobra.C
 	return &cobra.Command{
 		Use:   usage,
 		Short: short,
-		Long:  heredoc.Doc(long),
+		Long:  long,
 		RunE:  newRunE(fn, p...),
 	}
 }
