@@ -60,10 +60,7 @@ var CommonFlags = flag.Set{
 		Shorthand:   "e",
 		Description: "Set of environment variables in the form of NAME=VALUE pairs. Can be specified multiple times.",
 	},
-	flag.Bool{
-		Name:        "auto-confirm",
-		Description: "Will automatically confirm changes when running non-interactively.",
-	},
+	flag.Yes(),
 	flag.Int{
 		Name:        "wait-timeout",
 		Description: "Seconds to wait for individual machines to transition states and become healthy.",
@@ -91,11 +88,6 @@ var CommonFlags = flag.Set{
 		Default:     false,
 		Hidden:      true,
 	},
-	flag.String{
-		Name:        "vm-size",
-		Description: `The VM size to use when deploying for the first time. See "fly platform vm-sizes" for valid values`,
-		Aliases:     []string{"size"},
-	},
 	flag.Bool{
 		Name:        "ha",
 		Description: "Create spare machines that increases app availability",
@@ -115,20 +107,6 @@ var CommonFlags = flag.Set{
 		Name:        "no-public-ips",
 		Description: "Do not allocate any new public IP addresses",
 	},
-	flag.Int{
-		Name:        "vm-cpus",
-		Description: "Number of CPUs",
-		Aliases:     []string{"cpus"},
-	},
-	flag.String{
-		Name:        "vm-cpukind",
-		Description: "The kind of CPU to use ('shared' or 'performance')",
-	},
-	flag.Int{
-		Name:        "vm-memory",
-		Description: "Memory (in megabytes) to attribute to the VM",
-		Aliases:     []string{"memory"},
-	},
 	flag.StringArray{
 		Name:        "file-local",
 		Description: "Set of files in the form of /path/inside/machine=<local/path> pairs. Can be specified multiple times.",
@@ -149,6 +127,7 @@ var CommonFlags = flag.Set{
 		Name:        "only-regions",
 		Description: "Deploy to machines only in these regions. Multiple regions can be specified with comma separated values or by providing the flag multiple times. --only-regions iad,sea --only-regions syd will deploy to all three iad, sea, and syd regions. Applied before --exclude-regions. V2 machines platform only.",
 	},
+	flag.VMSizeFlags,
 }
 
 func New() (cmd *cobra.Command) {
@@ -199,7 +178,7 @@ func run(ctx context.Context) error {
 		return err
 	}
 
-	return DeployWithConfig(ctx, appConfig, flag.GetBool(ctx, "auto-confirm"), nil)
+	return DeployWithConfig(ctx, appConfig, flag.GetYes(ctx), nil)
 }
 
 func DeployWithConfig(ctx context.Context, appConfig *appconfig.Config, forceYes bool, optionalGuest *api.MachineGuest) (err error) {
@@ -273,29 +252,6 @@ func determineRelCmdTimeout(timeout string) (time.Duration, error) {
 	return time.Duration(asInt) * time.Second, nil
 }
 
-// ApplyFlagsToGuest applies CLI flags to a Guest
-// Returns true if any flags were applied
-func ApplyFlagsToGuest(ctx context.Context, guest *api.MachineGuest) bool {
-	modified := false
-	if flag.IsSpecified(ctx, "vm-size") {
-		guest.SetSize(flag.GetString(ctx, "vm-size"))
-		modified = true
-	}
-	if flag.IsSpecified(ctx, "vm-cpus") {
-		guest.CPUs = flag.GetInt(ctx, "vm-cpus")
-		modified = true
-	}
-	if flag.IsSpecified(ctx, "vm-memory") {
-		guest.MemoryMB = flag.GetInt(ctx, "vm-memory")
-		modified = true
-	}
-	if flag.IsSpecified(ctx, "vm-cpukind") {
-		guest.CPUKind = flag.GetString(ctx, "vm-cpukind")
-		modified = true
-	}
-	return modified
-}
-
 // in a rare twist, the guest param takes precedence over CLI flags!
 func deployToMachines(
 	ctx context.Context,
@@ -323,9 +279,7 @@ func deployToMachines(
 	}
 
 	if guest == nil {
-		guest = &api.MachineGuest{}
-		guest.SetSize(DefaultVMSize)
-		_ = ApplyFlagsToGuest(ctx, guest)
+		guest = flag.GetMachineGuest(ctx)
 	}
 
 	excludeRegions := make(map[string]interface{})
