@@ -6,6 +6,7 @@ import (
 	"fmt"
 	"math"
 	"net"
+	"slices"
 	"strconv"
 	"strings"
 	"time"
@@ -18,7 +19,6 @@ import (
 	"github.com/superfly/flyctl/internal/machine"
 	"github.com/superfly/flyctl/terminal"
 	"golang.org/x/exp/maps"
-	"golang.org/x/exp/slices"
 )
 
 type ProcessGroupsDiff struct {
@@ -158,8 +158,10 @@ func (md *machineDeployment) deployMachinesApp(ctx context.Context) error {
 
 		// Create machines for new process groups
 		groupsWithAutostopEnabled := make(map[string]bool)
-		total := len(processGroupMachineDiff.groupsNeedingMachines)
-		for idx, name := range maps.Keys(processGroupMachineDiff.groupsNeedingMachines) {
+		groups := maps.Keys(processGroupMachineDiff.groupsNeedingMachines)
+		total := len(groups)
+		slices.Sort(groups)
+		for idx, name := range groups {
 			fmt.Fprintf(md.io.Out, "No machines in group %s, launching a new machine\n", md.colorize.Bold(name))
 			leasableMachine, err := md.spawnMachineInGroup(ctx, name, idx, total, nil)
 			if err != nil {
