@@ -12,7 +12,6 @@ import (
 	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/build/imgsrc"
 	"github.com/superfly/flyctl/internal/cmdutil"
-	"github.com/superfly/flyctl/internal/command/deploy"
 	"github.com/superfly/flyctl/internal/flag"
 	"github.com/superfly/flyctl/internal/prompt"
 	"github.com/superfly/flyctl/iostreams"
@@ -149,7 +148,7 @@ func v2DetermineBaseAppConfig(ctx context.Context) (*appconfig.Config, bool, err
 			var err error
 			copyConfig, err = prompt.Confirm(ctx, "Would you like to copy its configuration to the new app?")
 			switch {
-			case prompt.IsNonInteractive(err) && !flag.GetBool(ctx, "auto-confirm"):
+			case prompt.IsNonInteractive(err) && !flag.GetYes(ctx):
 				return nil, false, err
 			case err != nil:
 				return nil, false, err
@@ -264,8 +263,10 @@ func getRegionByCode(ctx context.Context, regionCode string) (*api.Region, error
 func v2DetermineGuest(ctx context.Context, config *appconfig.Config, srcInfo *scanner.SourceInfo) (*api.MachineGuest, string, error) {
 	shared1x := api.MachinePresets["shared-cpu-1x"]
 	reason := "most apps need about 1GB of RAM"
-	if deploy.ApplyFlagsToGuest(ctx, shared1x) {
+
+	guest := flag.GetMachineGuest(ctx)
+	if shared1x != guest {
 		reason = "specified on the command line"
 	}
-	return shared1x, reason, nil
+	return guest, reason, nil
 }
