@@ -63,7 +63,7 @@ func runList(ctx context.Context) (err error) {
 		}
 
 	case "org":
-		org, err := orgs.OrgFromFirstArgOrSelect(ctx)
+		org, err := orgs.OrgFromEnvVarOrFirstArgOrSelect(ctx)
 		if err != nil {
 			return fmt.Errorf("failed retrieving org %w", err)
 		}
