@@ -7,9 +7,9 @@ import (
 	"github.com/spf13/cobra"
 
 	"github.com/superfly/flyctl/api"
+	"github.com/superfly/flyctl/flaps"
 	"github.com/superfly/flyctl/iostreams"
 
-	"github.com/superfly/flyctl/client"
 	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/config"
@@ -19,8 +19,7 @@ import (
 
 func newFork() *cobra.Command {
 	const (
-		long = `Volume forking creates an independent copy of a storage volume for backup, testing, and experimentation without altering the original data,
-but is currently restricted to same-host forks and may not be available for near-capacity hosts.`
+		long  = `Volume forking creates an independent copy of a storage volume for backup, testing, and experimentation without altering the original data.`
 		short = "Forks the specified volume"
 		usage = "fork <id>"
 	)
@@ -40,17 +39,14 @@ but is currently restricted to same-host forks and may not be available for near
 			Shorthand:   "n",
 			Description: "Name of the new volume",
 		},
-		flag.Bool{
-			Name:        "remote-fork",
-			Description: "Enables experimental cross-host volume forking",
-			Hidden:      true,
-			Default:     false,
-		},
 		flag.Bool{
 			Name:        "machines-only",
 			Description: "volume will be visible to machines platform only",
 			Hidden:      true,
-			Default:     false,
+		},
+		flag.Bool{
+			Name:        "require-unique-zone",
+			Description: "Require volume to be placed in separate hardware zone from existing volumes",
 		},
 	)
 
@@ -62,20 +58,15 @@ func runFork(ctx context.Context) error {
 	var (
 		cfg     = config.FromContext(ctx)
 		appName = appconfig.NameFromContext(ctx)
-		client  = client.FromContext(ctx).API()
 		volID   = flag.FirstArg(ctx)
 	)
 
-	app, err := client.GetAppCompact(ctx, appName)
+	flapsClient, err := flaps.NewFromAppName(ctx, appName)
 	if err != nil {
 		return err
 	}
 
-	if app.IsPostgresApp() {
-		return fmt.Errorf("This feature is not available for Postgres apps")
-	}
-
-	vol, err := client.GetVolume(ctx, volID)
+	vol, err := flapsClient.GetVolume(ctx, volID)
 	if err != nil {
 		return fmt.Errorf("failed to get volume: %w", err)
 	}
@@ -85,20 +76,24 @@ func runFork(ctx context.Context) error {
 		name = flag.GetString(ctx, "name")
 	}
 
-	machinesOnly := (app.PlatformVersion == "machines")
+	var machinesOnly *bool
 	if flag.IsSpecified(ctx, "machines-only") {
-		machinesOnly = flag.GetBool(ctx, "machines-only")
+		machinesOnly = api.Pointer(flag.GetBool(ctx, "machines-only"))
 	}
 
-	input := api.ForkVolumeInput{
-		AppID:          app.ID,
-		SourceVolumeID: vol.ID,
-		Name:           name,
-		MachinesOnly:   machinesOnly,
-		Remote:         machinesOnly,
+	var requireUniqueZone *bool
+	if flag.IsSpecified(ctx, "require-unique-zone") {
+		requireUniqueZone = api.Pointer(flag.GetBool(ctx, "require-unique-zone"))
 	}
 
-	volume, err := client.ForkVolume(ctx, input)
+	input := api.CreateVolumeRequest{
+		Name:              name,
+		MachinesOnly:      machinesOnly,
+		RequireUniqueZone: requireUniqueZone,
+		SourceVolumeID:    &vol.ID,
+	}
+
+	volume, err := flapsClient.CreateVolume(ctx, input)
 	if err != nil {
 		return fmt.Errorf("failed to fork volume: %w", err)
 	}
@@ -109,7 +104,7 @@ func runFork(ctx context.Context) error {
 		return render.JSON(out, volume)
 	}
 
-	if err := printVolume(out, volume); err != nil {
+	if err := printVolume(out, volume, appName); err != nil {
 		return err
 	}
 
